#!/bin/sh

### BEGIN INIT INFO
# Provides:          maxwell-prepare
# Required-Start:    $syslog
# Required-Stop:     $syslog
# Default-Start:     5
# Default-Stop:      0 1 2 3 4 6
# Short-Description: Maxwell environment preparation
# Description:
### END INIT INFO

. /etc/init.d/init-functions

ENVFILE=/var/run/environment

do_start ()
{
    # Truncate environment file
    : > ${ENVFILE}

    # If booting from FLASH, Configure loopback interface before IPC daemon gets started.
    # Otherwise if booting from NFS create nfs_mode lock to disable SysConf-base network configuration.
    # TODO Remove when GPMB-554 is done
    NFS_MOUNTED=`mount | grep nfs`
    if [ -z "${NFS_MOUNTED}" ]; then
        nohup ip addr add 127.0.0.1 dev lo
        nohup ip link set dev lo up
    else
        touch /var/lock/nfs_mode
    fi

    # Configure keypad for target's Qt-based applications
    KEYBOARD=`ls -la /sys/class/input | grep keypad | grep event | awk '{ print $9}'`
    export QWS_KEYBOARD="LinuxInput:/dev/input/${KEYBOARD}"
    if [ -n ${KEYBOARD} ]; then
        log_success_msg "Keypad detected and set for ${KEYBOARD}"
    else
        log_warning_msg "Keypad has not been detected !"
    fi

    echo "QWS_KEYBOARD=\"${QWS_KEYBOARD}\"" >> ${ENVFILE}

    # Configure hookswitch
    HOOKSWITCH=`ls -la /sys/class/input | grep hookswitch | grep event | awk '{ print $9}'`
    if [ -n ${HOOKSWITCH} ]; then
        log_success_msg "Hookswitch detected and set for ${HOOKSWITCH}"
    else
        log_warning_msg "Hookswitch has not been detected !"
    fi

    echo "HOOKSWITCH=\"${HOOKSWITCH}\"" >> ${ENVFILE}

    sqlite3 /www/pages/webui.db "update webui_users set sessionID=null;"

    rm -f /dev/shm/SETTINGS_WORKSPACE
    rm -f /dev/shm/SETTINGS_WORKSPACE_READY
}

do_stop ()
{
    unset QWS_KEYBOARD;
}

case $1 in
    start)
        do_start;
        ;;

    stop)
        do_stop;
        ;;
    *)
        echo "Usage: $0 {start|stop}"
        exit 1
        ;;
esac

