#!/bin/sh
dspg_dflt_dev_name=dspgdvf99css
dspg_dflt_dev_number=3
aloop_pid_file=/var/run/aloop.pid
kernel=$1
number=$2
devpath=$3
major=$4
minor=$5
id=$6

dbg=0
log_file=/data/alsa_aloop.info
if [ $dbg -ne 0 ] ; then
	echo "Hello" > $log_file ;
	echo "kernel:$kernel" >> $log_file ;
	echo "number:$number" >> $log_file ;
	echo "devpath:$devpath" >> $log_file ;
	echo "id:$id" >> $log_file ;
	echo "major:$major" >> $log_file ;
	echo "minor:$minor" >> $log_file ;
fi
# id could be the same than card_id
# number could be the same than ctrl_number

### 1.) check if aloop is already running
aloop_pid=$(ps | grep "aloop" | grep -v "grep" | grep -v "aloop.sh" | awk '{print $1}')
### 2.) get ID from sound card
# devpath is present during add and remove, id not
# devpath:/devices/snd-dvf99-mach-drv.13/sound/card0/controlC0
# devpath:/devices/300000.usb/usb1/1-1/1-1:1.0/sound/card1/controlC1
if [ "$devpath" = "" ] ; then
	[ $dbg -ne 0 ] && echo "devpath: >$devpath< is missing!"  >> $log_file ;
	exit 0
fi
card_id=$(echo "$devpath" | sed -n 's/.*\(card[0-9][0-9]*\).*/\1/p')
### 3.a) check if it is an USB sound device
is_usb_device=0
substring="devices/300000.usb"
if [ "${devpath/$substring}" = "$devpath" ] ; then
  [ $dbg -ne 0 ] && echo "${substring} is not in ${devpath}"  >> $log_file ;
else
  [ $dbg -ne 0 ] && echo "${substring} was found in ${devpath}"  >> $log_file ;
  is_usb_device=1
fi
### 3.b) check if it is a dvf99 sound device
is_dvf_device=0
substring="devices/snd-dvf99-mach-drv"
if [ "${devpath/$substring}" = "$devpath" ] ; then
  [ $dbg -ne 0 ] && echo "${substring} is not in ${devpath}"  >> $log_file ;
else
  [ $dbg -ne 0 ] && echo "${substring} was found in ${devpath}"  >> $log_file ;
  is_dvf_device=1
fi
### 4.)
if [ "$ACTION" = "add" ] ; then
	[ $dbg -ne 0 ] && echo "$ACTION $card_id" >> $log_file ;
	alsa_name=$(cat /proc/asound/$card_id/id)
	[ $dbg -ne 0 ] && echo "$alsa_name" >> $log_file ;
	# check for play, capture and control device
	# get ctrl number controlC0
	ctrl_number=$(echo "$kernel" | sed 's/[^0-9]//g')
	dev_number=0
	if [ $is_dvf_device = 1 ] ; then
		dev_number=$dspg_dflt_dev_number
	fi
	capt_name="pcmC"$ctrl_number"D"$dev_number"c"
	[ $dbg -ne 0 ] && echo "$capt_name" >> $log_file ;
	play_name="pcmC"$ctrl_number"D"$dev_number"p"
	[ $dbg -ne 0 ] && echo "$play_name" >> $log_file ;
	play_name="/sys/class/sound/"$play_name
	capt_name="/sys/class/sound/"$capt_name
	if [ -e $capt_name ] && [ -e $play_name ] ; then
		[ $dbg -ne 0 ] && echo "$play_name + $capt_name exists" >> $log_file ;
		# currently, we only connect if it is an USB device
		if [ $is_usb_device = 1 ] ; then
			# and dvf99 sound card is activated
			if [ -e "/proc/asound/$dspg_dflt_dev_name" ] ; then
				# aloop plughw:Control plughw:dspgdvf99css,3
				[ $dbg -ne 0 ] && echo "/usr/bin/aloop -p $aloop_pid_file -u plughw:$alsa_name,0 -d plughw:$dspg_dflt_dev_name,$dspg_dflt_dev_number &" >> $log_file ;
				/usr/bin/aloop -p $aloop_pid_file -u plughw:$alsa_name,0 -d plughw:$dspg_dflt_dev_name,$dspg_dflt_dev_number &
			fi
		fi
		if [ $is_dvf_device = 1 ] ; then
			# search for an USB device
			alsa_usb_numner=$(cat /proc/asound/cards | grep USB | grep '\[' | tr -s ' ' | cut -d ' ' -f 2)
			alsa_usb_name=$(cat /proc/asound/card$alsa_usb_numner/id)
			capt_name="pcmC"$alsa_usb_numner"D0c"
			[ $dbg -ne 0 ] && echo "$capt_name" >> $log_file ;
			play_name="pcmC"$alsa_usb_numner"D0p"
			[ $dbg -ne 0 ] && echo "$play_name" >> $log_file ;
			play_name="/sys/class/sound/"$play_name
			capt_name="/sys/class/sound/"$capt_name
			if [ -e $capt_name ] && [ -e $play_name ] ; then
				[ $dbg -ne 0 ] && echo "$play_name + $capt_name exists" >> $log_file ;
				echo "/usr/bin/aloop -p $aloop_pid_file -u plughw:$alsa_usb_name,0 -d plughw:$dspg_dflt_dev_name,$dspg_dflt_dev_number &" >> $log_file ;
				/usr/bin/aloop -p $aloop_pid_file -u plughw:$alsa_usb_name,0 -d plughw:$dspg_dflt_dev_name,$dspg_dflt_dev_number &
			fi
		fi
	fi
fi
if [ "$ACTION" = "remove" ] ; then
	[ $dbg -ne 0 ] && echo "$ACTION $card_id" >> $log_file ;
	# is aloop still running, kill it
	if [ "$aloop_pid"  = "" ] ; then
		[ $dbg -ne 0 ] && echo "aloop was not running." >> $log_file ;
	else
		[ $dbg -ne 0 ] && echo "kill $aloop_pid" >> $log_file ;
		kill $aloop_pid
		sleep 1
		if [ -e $aloop_pid_file ] ; then
			[ $dbg -ne 0 ] && echo "Uses kill -9 for aloop!" >> $log_file ;
			kill -9 $aloop_pid &
			rm -f $aloop_pid_file
		fi
	fi
fi
[ $dbg -ne 0 ] && echo "done!" >> $log_file ;
exit 0


# $kernel, %k
#
#     The kernel name for this device.
# $number, %n
#
#     The kernel number for this device. For example, "sda3" has kernel number "3".
# $devpath, %p
#
#     The devpath of the device.
# $id, %b
#
#     The name of the device matched while searching the devpath upwards for SUBSYSTEMS, KERNELS, DRIVERS, and ATTRS.
# $driver
#
#     The driver name of the device matched while searching the devpath upwards for SUBSYSTEMS, KERNELS, DRIVERS, and ATTRS.
# $attr{file}, %s{file}
#
#     The value of a sysfs attribute found at the device where all keys of the rule have matched. If the matching device does not have such an attribute, and a previous KERNELS, SUBSYSTEMS, DRIVERS, or ATTRS test selected a parent device, then the attribute from that parent device is used.
#
#     If the attribute is a symlink, the last element of the symlink target is returned as the value.
# $env{key}, %E{key}
#
#     A device property value.
# $major, %M
#
#     The kernel major number for the device.
# $minor, %m
#
#     The kernel minor number for the device.
# $result, %c
#
#     The string returned by the external program requested with PROGRAM. A single part of the string, separated by a space character, may be selected by specifying the part number as an attribute: "%c{N}". If the number is followed by the "+" character, this part plus all remaining parts of the result string are substituted: "%c{N+}".
# $parent, %P
#
#     The node name of the parent device.
# $name
#
#     The current name of the device. If not changed by a rule, it is the name of the kernel device.
# $links
#
#     A space-separated list of the current symlinks. The value is only set during a remove event or if an earlier rule assigned a value.
# $root, %r
#
#     The udev_root value.
# $sys, %S
#
#     The sysfs mount point.
